#!/bin/bash

set -eu

if ! [ -f /app/data/.installed ]; then
  echo "Fresh installation, setting up..."
  rsync -a /app/code/data-orig/ /app/data/
  dd if=/dev/urandom bs=1 count=1024 2>/dev/null | sha1sum | awk '{ print $1 }' > /app/data/.salt
  mkdir -p /app/data/users/admin
  cat > /app/data/users/admin/config.php <<EOF
<?php
return array (
  'language' => 'en',
  'passwordHash' => '\$2a\$09\$lO5xTAsfRCG1rSssJgHtTeiweXj2VwGN/JfuexIMpsQWzKoFVoklm',
  'apiPasswordHash' => '',
);
?>
EOF
  touch /app/data/users/admin/log.txt
  rm /app/data/do-install.txt
  php /app/code/setup_db.php
  touch /app/data/.installed
  echo "Done."
fi

echo "Creating config file"
SALT=$(cat /app/data/.salt)
cat > /app/data/config.php <<EOF
<?php
 return array (
  'salt' => '${SALT}',
  'base_url' => 'https://${APP_DOMAIN}/p',
  'title' => 'FreshRSS',
  'default_user' => 'admin',
  'auth_type' => 'form',
  'db' => 
  array (
    'type' => 'mysql',
    'host' => '${MYSQL_HOST}',
    'user' => '${MYSQL_USERNAME}',
    'password' => '${MYSQL_PASSWORD}',
    'base' => '${MYSQL_DATABASE}',
    'prefix' => '',
    'pdo_options' => 
    array (
    ),
  ),
  'pubsubhubbub_enabled' => true,
);
EOF

chown -R www-data.www-data /app/data

echo "Trying to update feeds every 60 secs"
while true; do
  sleep 60
  curl 'http://localhost:8000/p/i/?c=feed&a=actualize' >/dev/stdout 2>/dev/stderr
done &

echo "Starting apache"
APACHE_CONFDIR="" source /etc/apache2/envvars
rm -f "${APACHE_PID_FILE}"
exec /usr/sbin/apache2 -DFOREGROUND
